@@ -24,23 +24,27 @@ from fabric.utils import abort
 
 from littlechef import cookbook_paths
 
-
 knife_installed = True
 
 
-def get_node(name):
+def get_node(name, merged=False):
     """Returns a JSON node file as a dictionary"""
-    node_path = os.path.join("nodes", name + ".json")
-    if not os.path.exists(node_path):
-        return {'run_list': []}
-    # Read node.json
-    with open(node_path, 'r') as f:
-        try:
-            node = json.loads(f.read())
-        except json.JSONDecodeError as e:
-            msg = 'LittleChef found the following error in'
-            msg += ' "{0}":\n                {1}'.format(node_path, str(e))
-            abort(msg)
+    if merged:
+        node_path = os.path.join("data_bags", "node", name.replace('.', '_') + ".json")
+    else:
+        node_path = os.path.join("nodes", name + ".json")
+    if os.path.exists(node_path):
+        # Read node.json
+        with open(node_path, 'r') as f:
+            try:
+                node = json.loads(f.read())
+            except json.JSONDecodeError as e:
+                msg = 'LittleChef found the following error in'
+                msg += ' "{0}":\n                {1}'.format(node_path, str(e))
+                abort(msg)
+    else:
+        print "Creating new node file '{0}.json'".format(name)
+        node = {'run_list': []}
     # Add node name so that we can tell to which node it is
     node['name'] = name
     return node
@@ -442,31 +446,3 @@ def get_margin(length):
         margin_left = "\t\t\t\t"
         chars = 4
     return margin_left
-
-
-def credentials(*args, **kwargs):
-    """Override default credentials with contents of .ssh/config,
-
-    Only done if credentials are properly defined
-    """
-    if env.ssh_config:
-        credentials = env.ssh_config.lookup(env.host)
-        # translate from ssh params to fabric params
-        if 'identityfile' in credentials:
-            credentials['key_filename'] = credentials['identityfile']
-        # SSH LogLevel != overall env loglevel, so don't override the env's
-        # loglevel with SSH's
-        if 'loglevel' in credentials:
-            del credentials['loglevel']
-        credentials.update(kwargs)
-    else:
-        credentials = kwargs
-    # Expand the home directory of 'key_filename', as 'ssh' won't do it
-    if credentials.get('key_filename'):
-        credentials['key_filename'] = os.path.expanduser(
-                                        credentials['key_filename'])
-    # If ssh config defines a different Hostname string (be it domain or IP),
-    # override 'host_string'
-    if 'hostname' in credentials:
-        credentials['host_string'] = credentials['hostname']
-    return settings(*args, **credentials)
